# -*- coding: utf-8 -*-
"""
Created on Fri Oct  3 11:13:18 2014

@author: pattyf@berkeley.edu

This file reads in a text file of addresses and geocodes them using the
Data Science toolkit (DSTK) - http://www.datasciencetoolkit.org/developerdocs
The output is formatted as a comma delimited text file
You must install dstk python module - see website for instructions on how
to do that.
"""

import dstk

dstk = dstk.DSTK()

#Usage Example
#j = dstk.street2coordinates('2543 Graystone Place, Simi Valley, CA 93065')
#print(j)

#open a file to write output to
# YOU WILL NEED TO ALTER PATH AND FILE NAME
outfile=open('/Users/patty/Documents/geocoding/dlab-geocoding-tutorial-files/j2_ten_addresses_geocoded.csv','w')

# Read in addresses
# They are in a text file in following format:
# no header, no quotes, mixed case, line separated addresses,commas between address components
#----------------------------------------
#4728 SCOTIA AVE,Oakland,CA,94605
#10709 COTTER ST,Oakland,,94605
#....
# YOU WILL NEED TO ALTER PATH AND FILE NAME
infile = open('/Users/patty/Documents/geocoding/dlab-geocoding-tutorial-files/ten_addresses_in_forpy.txt', 'r')

mylist = infile.readlines()

#Process input addresses chunked 2500 at a time
n=2500
splitlists = [mylist[i:i+n] for i in range(0, len(mylist), n-1)]
splitlists[-1].append(splitlists[0][0])

for myarray in splitlists:
    data = dstk.street2coordinates(myarray)

#Process the output from DSTK
mydelim= ","

mycount=0
numcol = 0
thisRec = []
badRecPad = ","

for d in data:
   
   if mycount < 1:
       # If here we have not yet processed a record
       # We grab the keys to create the column headers in the output file
       thisRec.append("inaddress")
       
       if hasattr(data[d], 'keys'):
           #print(data[d].keys())
           thisRec.extend(sorted(data[d].keys()))
       else:
           thisRec.extend("NO_HEADER_ROW")
           
       myline = ",".join(thisRec)
       #print(myline)
       outfile.write(myline + "\n")
       
       numcol = len(thisRec)
       #print("number of colums: " + str(numcol))
       mycount += 1 
       
       #Reset the line after writing out the header
       thisRec = []
       myline = "" 
          
       #Also we use the badRecPad to create column separators for
       #addresses for which no data was returned
       for i in range(1,numcol-2):
           badRecPad = badRecPad + ","
           
   #else:
   thisRec.append("\"" + d.rstrip("\n") + "\"")    
   
   if data[d]:
       for k,v in sorted(data[d].items()):
           #thisRec.append("\""+str(v)+"\"")
           thisRec.append(str(v))
   else:
       #no data returned
       #todo: need delim numcolumn times!
       thisRec.append(badRecPad)

   #myline = "|".join(thisRec)
   myline = ",".join(thisRec)
   #print(myline)
   outfile.write(myline + "\n")
   thisRec = []
   myline = "" 

outfile.close()

