# -*- coding: utf-8 -*-
"""
Created on Fri Oct 10 11:19:24 2014
@name: parse_dstk_output.py
@author:juan shishido,  pattyf@berkeley.edu

This file reads in a text file of geocoded addresses and uses the FCC census API to
determine census tract and block group id for each address location

"""

import json
import sys
import requests
import pandas as pd

#Here is what input data look like
'''
inaddr,confidence,country_code,country_code3,country_name,fips_county,latitude,locality,longitude,region,street_address,street_name,street_number
"10520 PEBBLE BEACH DR,Oakland,CA,94605",0.878,US,USA,United States,06001,37.761226,Oakland,-122.127254,CA,10520 Pebble Beach Dr,Pebble Beach Dr,10520
"10834 GOLF LINKS RD,Oakland,CA,94605",1.0,US,USA,United States,06001,37.753894,Oakland,-122.126869,CA,10834 Golf Links Rd,Golf Links Rd,10834
'''

# We use an FCC API to convert latitude and longitude to census block and tract ids
# http://www.fcc.gov/developers/census-block-conversions-api
url = 'http://data.fcc.gov/api/block/2010/find?format=json&latitude='

#get names of files
# YOU WILL NEED TO UPDATE THE FILE REFERENCES
infilename = "/Users/patty/Documents/geocoding/dlab-geocoding-tutorial-files/ten_addresses_geocoded.csv"
outfilename = "/Users/patty/Documents/geocoding/dlab-geocoding-tutorial-files/ten_addresses_geocoded_wfips.csv"

#open a file to write output to
outfile=open(outfilename,'w')

df = pd.read_csv(infilename, sep=",")

#get the header for the output file
myheader = df.columns.values.tolist()

myheader.append('blockgroupid')
myheader.append('tractid')
prettyheader = ','.join(myheader)
#print(prettyheader)
outfile.write(prettyheader)

df['blockgroupid'] = ''
df['tractid'] = ''

for i, row in df.iterrows():
    if i%200 == 0: 
        print 'processing row: ', i

    if row['latitude']>0:
        myurl = url+str(row['latitude'])+'&longitude='+str(row['longitude'])
        #print(myurl)
        
        resp = requests.get(myurl)
        data = json.loads(resp.text)

        #print data
        df['blockgroupid'][i] = data['Block']['FIPS']
        df['tractid'][i] = df['blockgroupid'][i][0:11]
    else:
         df['blockgroupid'][i] = ""
         df['tractid'][i] = ""
        
df.to_csv(outfilename, sep=",",index=False)

outfile.close()
